@@ -733,6 +733,7 @@ noof\
 nose\
 oct\
 pacman\
+paterson\
 penrose\
 petal\
 petri\
@@ -758,6 +759,7 @@ solitaire\
 space\
 sphere\
 spiral\
+spirolateral\
 spline\
 sproingies\
 stairs\
