@@ -161,6 +161,7 @@ public class xlockApplet extends Applet implements ItemListener {
 		list.add("nose");
 		list.add("oct");
 		list.add("pacman");
+		list.add("paterson");
 		list.add("penrose");
 		list.add("petal");
 		list.add("petri");
@@ -186,6 +187,7 @@ public class xlockApplet extends Applet implements ItemListener {
 		list.add("space");
 		list.add("sphere");
 		list.add("spiral");
+		list.add("spirolateral");
 		list.add("spline");
 		list.add("sproingies");
 		list.add("stairs");
