@@ -1,7 +1,7 @@
 /* -*- Mode: C; tab-width: 4 -*- */
 /* apollonian --- Apollonian Circles */
 
-#if !defined( lint ) && !defined( SABER )
+#if 0
 static const char sccsid[] = "@(#)apollonian.c	5.02 2001/07/01 xlockmore";
 #endif
 
@@ -65,18 +65,21 @@ static const char sccsid[] = "@(#)apollonian.c	5.02 2001/07/01 xlockmore";
  */
 
 #ifdef STANDALONE
-#define MODE_apollonian
-#define PROGCLASS "Apollonian"
-#define HACK_INIT init_apollonian
-#define HACK_DRAW draw_apollonian
-#define apollonian_opts xlockmore_opts
-#define DEFAULTS "*delay: 1000000 \n" \
- "*count: 64 \n" \
- "*cycles: 20 \n" \
- "*ncolors: 64 \n"
-#include "xlockmore.h"		/* in xscreensaver distribution */
+# define MODE_apollonian
+# define DEFAULTS	"*delay: 1000000 \n" \
+			"*count: 64 \n" \
+			"*cycles: 20 \n" \
+			"*ncolors: 64 \n" \
+			"*font:    fixed" "\n" \
+			"*fpsTop: true     \n" \
+			"*fpsSolid: true   \n" \
+			"*ignoreRotation: true" \
+
+# define reshape_apollonian 0
+# define apollonian_handle_event 0
+# include "xlockmore.h"		/* in xscreensaver distribution */
 #else /* STANDALONE */
-#include "xlock.h"		/* in xlockmore distribution */
+# include "xlock.h"		/* in xlockmore distribution */
 #endif /* STANDALONE */
 
 #ifdef MODE_apollonian
@@ -105,7 +108,7 @@ static OptionStruct desc[] =
         {(char *) "-/+label", (char *) "turn on/off alternate space and number labeling"},
 };
 
-ModeSpecOpt apollonian_opts =
+ENTRYPOINT ModeSpecOpt apollonian_opts =
 {sizeof opts / sizeof opts[0], opts, sizeof vars / sizeof vars[0], vars, desc};
 
 #ifdef DOFONT
@@ -115,9 +118,9 @@ extern XFontStruct *getFont(Display * display);
 #ifdef USE_MODULES
 ModStruct   apollonian_description =
 {"apollonian", "init_apollonian", "draw_apollonian", "release_apollonian",
- "init_apollonian", "init_apollonian", (char *) NULL, &apollonian_opts,
+ "init_apollonian", "init_apollonian", "free_apollonian", &apollonian_opts,
  1000000, 64, 20, 1, 64, 1.0, "",
- "Shows Apollonian circles", 0, NULL};
+ "Shows Apollonian Circles", 0, NULL};
 
 #endif
 
@@ -132,7 +135,9 @@ typedef struct {
         double x, y;    /* euclidean bend times euclidean position */
 } circle;
 
-typedef enum {euclidean = 0, spherical = 1, hyperbolic = 2} Space;
+enum space {
+  euclidean = 0, spherical = 1, hyperbolic = 2
+};
 
 static const char * space_string[] = {
   "euclidean",
@@ -154,8 +159,8 @@ c * z3 = (q123 + a * i)^2/(a*(a+b)) where q123 = sqrt(a*b+a*c+b*c)
 d * z4 = (q124 + a * i)^2/(a*(a+b)) where q124 = q123 - a - b
 If (e,x,y) represents the Euclidean circle (1/e,x/e,y/e) (so that e is
 the label in the standard picture) then the "spherical label" is
-(e^2+x^2+y^2-1)/(2*e) (an integer!)  and the "hyperbolic label", is
-calulated by h + s = e.
+(e^2+x^2+y^2-1)/(2*e) (an integer!) and the "hyperbolic label", is
+calculated by h + s = e.
 */
 static circle examples[][4] = {
 { /* double semi-bounded */
@@ -283,7 +288,7 @@ Hyperbolic
 typedef struct {
 	int         size;
 	XPoint      offset;
-	Space       geometry;
+	int         geometry;
 	circle      c1, c2, c3, c4;
 	int         color_offset;
 	int         count;
@@ -448,7 +453,7 @@ iceil(int a, int b)
 }
 
 static double
-geom(Space geometry, int e, int p, int q)
+geom(int geometry, int e, int p, int q)
 {
 	int g = (geometry == spherical) ? -1 :
 		(geometry == hyperbolic) ? 1 : 0;
@@ -505,7 +510,7 @@ static void
 p(ModeInfo *mi, circle c)
 {
 	apollonianstruct *cp = &apollonians[MI_SCREEN(mi)];
-	char string[14];
+	char string[15];
 	double g, e;
 	int g_width;
 
@@ -612,33 +617,39 @@ p(ModeInfo *mi, circle c)
 
 #define BIG 7
 static void
-f(ModeInfo *mi, circle c1, circle c2, circle c3, circle c4)
+f(ModeInfo *mi, circle c1, circle c2, circle c3, circle c4, int depth)
 {
 	apollonianstruct *cp = &apollonians[MI_SCREEN(mi)];
 	int e = (int) ((cp->c1.e >= 0.0) ? 1.0 : -cp->c1.e);
         circle c;
 
+	if (depth > MI_RECURSION_DEPTH(mi)) MI_RECURSION_DEPTH(mi) = depth;
+
         c.e = 2*(c1.e+c2.e+c3.e) - c4.e;
         c.s = 2*(c1.s+c2.s+c3.s) - c4.s;
         c.h = 2*(c1.h+c2.h+c3.h) - c4.h;
         c.x = 2*(c1.x+c2.x+c3.x) - c4.x;
         c.y = 2*(c1.y+c2.y+c3.y) - c4.y;
-        if (c.e > cp->size * e || c.x / c.e > BIG || c.y / c.e > BIG ||
+        if (c.e == 0 ||
+		c.e > cp->size * e || c.x / c.e > BIG || c.y / c.e > BIG ||
             c.x / c.e < -BIG || c.y / c.e < -BIG)
                 return;
         p(mi, c);
-        f(mi, c2, c3, c, c1);
-        f(mi, c1, c3, c, c2);
-        f(mi, c1, c2, c, c3);
+        f(mi, c2, c3, c, c1, depth+1);
+        f(mi, c1, c3, c, c2, depth+1);
+        f(mi, c1, c2, c, c3, depth+1);
 }
 
 static void
-free_apollonian(
+free_apollonian_screen(
 #ifdef DOFONT
 		Display *display,
 #endif
 		apollonianstruct *cp)
 {
+	if (cp == NULL) {
+		return;
+	}
 	if (cp->quad != NULL) {
 		free(cp->quad);
 		cp->quad = (apollonian_quadruple *) NULL;
@@ -653,6 +664,18 @@ free_apollonian(
 		cp->font = None;
 	}
 #endif
+	cp = NULL;
+}
+
+ENTRYPOINT void
+free_apollonian(ModeInfo * mi)
+{
+	apollonianstruct *ap = &apollonians[MI_SCREEN(mi)];
+	free_apollonian_screen(
+#ifdef DOFONT
+		MI_DISPLAY(mi),
+#endif
+		ap);
 }
 
 #ifndef DEBUG
@@ -673,17 +696,13 @@ randomize_c(int randomize, circle * c)
 }
 #endif
 
-void
+ENTRYPOINT void
 init_apollonian(ModeInfo * mi)
 {
 	apollonianstruct *cp;
 	int i;
 
-	if (apollonians == NULL) {
-		if ((apollonians = (apollonianstruct *) calloc(MI_NUM_SCREENS(mi),
-					     sizeof (apollonianstruct))) == NULL)
-			return;
-	}
+	MI_INIT (mi, apollonians);
 	cp = &apollonians[MI_SCREEN(mi)];
 
 	cp->size = MAX(MIN(MI_WIDTH(mi), MI_HEIGHT(mi)) - 1, 1);
@@ -712,7 +731,7 @@ init_apollonian(ModeInfo * mi)
 		dquad(cp->count, cp->quad);
 	}
 	cp->game = NRAND(PREDEF_CIRCLE_GAMES + cp->count);
-	cp->geometry = (Space) ((cp->game && cp->altgeom) ? NRAND(3) : 0);
+	cp->geometry = (int) ((cp->game && cp->altgeom) ? NRAND(3) : 0);
 
 	if (cp->game < (int) PREDEF_CIRCLE_GAMES) {
 		cp->c1 = examples[cp->game][0];
@@ -771,9 +790,10 @@ init_apollonian(ModeInfo * mi)
 	randomize_c(i, &(cp->c3));
 	randomize_c(i, &(cp->c4));
 #endif
+	MI_RECURSION_DEPTH(mi) = -1;
 }
 
-void
+ENTRYPOINT void
 draw_apollonian(ModeInfo * mi)
 {
 	apollonianstruct *cp;
@@ -794,30 +814,30 @@ draw_apollonian(ModeInfo * mi)
 			p(mi, cp->c4);
 			break;
 		case 1:
-			f(mi, cp->c1, cp->c2, cp->c3, cp->c4);
+			f(mi, cp->c1, cp->c2, cp->c3, cp->c4, 0);
 			break;
 		case 2:
-			f(mi, cp->c1, cp->c2, cp->c4, cp->c3);
+			f(mi, cp->c1, cp->c2, cp->c4, cp->c3, 0);
 			break;
 		case 3:
-			f(mi, cp->c1, cp->c3, cp->c4, cp->c2);
+			f(mi, cp->c1, cp->c3, cp->c4, cp->c2, 0);
 			break;
 		case 4:
-			f(mi, cp->c2, cp->c3, cp->c4, cp->c1);
+			f(mi, cp->c2, cp->c3, cp->c4, cp->c1, 0);
 		}
 	}
 	if (++cp->time > MI_CYCLES(mi))
 		init_apollonian(mi);
 }
 
-void
+ENTRYPOINT void
 release_apollonian(ModeInfo * mi)
 {
 	if (apollonians != NULL) {
 		int         screen;
 
 		for (screen = 0; screen < MI_NUM_SCREENS(mi); screen++)
-			free_apollonian(
+			free_apollonian_screen(
 #ifdef DOFONT
 				MI_DISPLAY(mi),
 #endif
@@ -827,4 +847,6 @@ release_apollonian(ModeInfo * mi)
 	}
 }
 
+XSCREENSAVER_MODULE ("Apollonian", apollonian)
+
 #endif /* MODE_apollonian */
