@@ -339,14 +339,14 @@ drawWedge(mballstruct * op, Bool wire, int wedge, int band)
 	return polys;
 }
 
-static void 
+static void
 drawBand(mballstruct * op, int band) {
 	int wedge;
 	for (wedge = 0; wedge < op->wedges; wedge++)
 		drawWedge(op, False, wedge, op->bands - 1 - band);
 }
 
-static void 
+static void
 drawNotBand(mballstruct * op, int notBand) {
 	int wedge, band;
 	for (wedge = 0; wedge < op->wedges; wedge++)
@@ -355,7 +355,7 @@ drawNotBand(mballstruct * op, int notBand) {
 				drawWedge(op, False, wedge, op->bands - 1 - band);
 }
 
-static void 
+static void
 drawHalf(mballstruct * op, int offset) {
 	int wedge, band;
 	for (wedge = 0; wedge < op->wedges / 2; wedge++)
@@ -641,7 +641,7 @@ drawSphere(mballstruct * op)
 }
 
 /* From xmball used by permission ;) */
- 
+
 static int mapDirToWedge[(MAX_WEDGES - MIN_WEDGES) / 2 + 1][COORD] =
 {
 	{
@@ -777,7 +777,7 @@ moveControlCb(mballstruct *op, int wedge, int direction)
 	}
 }
 
-void
+static void
 moveMball(mballstruct *op, int wedge, int band, int direction, int control)
 {
 	if (control) {
@@ -833,7 +833,7 @@ shuffle(ModeInfo * mi)
 
 	if (MI_IS_FULLRANDOM(mi))
 		op->wedges = NRAND((MAX_WEDGES - MIN_WEDGES) / 2 + 1) * 2 + MIN_WEDGES;
-	else if (wedges % 2 == 0 && wedges >= MIN_WEDGES && wedges <= MAX_WEDGES) 
+	else if (wedges % 2 == 0 && wedges >= MIN_WEDGES && wedges <= MAX_WEDGES)
 		op->wedges = wedges;
 	else
 		op->wedges = NRAND((MAX_WEDGES - MIN_WEDGES) / 2 + 1) * 2 + MIN_WEDGES;
@@ -1203,7 +1203,7 @@ draw_mball(ModeInfo * mi)
 					if (op->movement.direction >= COORD)
 						op->movement.direction = 3 * COORD -
 							op->movement.direction;
-					else	
+					else
 						op->movement.direction = (op->movement.direction +
 							(COORD / 2)) % COORD;
 				} else {
