@@ -41,6 +41,18 @@ static const char sccsid[] = "@(#)moebius.c	5.01 2001/03/01 xlockmore";
  * Marcelo F. Vianna (Jun-01-1997)
  *
  * Revision History:
+ * 01-Mar-2025: Many tweaks made possible due to computing power advances after
+ *              that many years:
+ *              - Increased number of triangles on polyhedra faces and spheres;
+ *              - Made animation smoother by reducing angles and steps granu-
+ *                larity per cycle (ants positions and strip rotation velocity)
+ *                in addition to reducing the delay between each cycle;
+ *              - Adjusted lines thickness for better visibility on newer screen
+ *                resolutions like 2K, 4K, 5K and 8K.
+ *              OBS: Interesting experience to be messing with my own code
+ *              after almost 30 years since the first version and 23 years after
+ *              the last previous change.
+ *              <marcelofvianna AT gmail.com>
  * 05-Apr-2002: Removed all gllist uses (fix some bug with nvidia driver)
  * 01-Mar-2001: backported from xscreensaver by lassauge AT users.sourceforge.net
  *    Feb-2001: Made motion and rotation be smoother Jamie Zawinski
@@ -84,7 +96,7 @@ static const char sccsid[] = "@(#)moebius.c	5.01 2001/03/01 xlockmore";
 #ifdef STANDALONE
 # define MODE_moebius
 # define DEFAULTS			"*cycles:	1       \n"	\
-					"*delay:	30000   \n"	\
+					"*delay:	15000   \n"	\
 					"*showFps:      False   \n"	\
 					"*wireframe:	False	\n"
 
@@ -133,7 +145,7 @@ ENTRYPOINT ModeSpecOpt moebius_opts =
 ModStruct   moebius_description =
 {"moebius", "init_moebius", "draw_moebius", "release_moebius",
  "draw_moebius", "change_moebius", (char *) NULL, &moebius_opts,
- 30000, 1, 1, 1, 64, 1.0, "",
+ 15000, 1, 1, 1, 64, 1.0, "",
  "Shows Moebius Strip II, an Escher-like GL scene with ants", 0, NULL};
 
 #endif
@@ -160,12 +172,11 @@ typedef struct {
 	GLXContext *glx_context;
 #endif
 	GLint       WindH, WindW;
-	GLfloat     step;
 	GLfloat     ant_position;
-	GLfloat rotx, roty, rotz;	   /* current object rotation */
-	GLfloat dx, dy, dz;		   /* current rotational velocity */
-	GLfloat ddx, ddy, ddz;	   /* current rotational acceleration */
-	GLfloat d_max;			   /* max velocity */
+	GLfloat     rotx, roty, rotz;	   /* current object rotation */
+	GLfloat     dx, dy, dz;		   /* current rotational velocity */
+	GLfloat     ddx, ddy, ddz;	   /* current rotational acceleration */
+	GLfloat     d_max;		   /* max velocity */
 
 } moebiusstruct;
 
@@ -221,7 +232,7 @@ mySphere(float radius)
 	if ((quadObj = gluNewQuadric()) == 0)
 		return False;
 	gluQuadricDrawStyle(quadObj, (GLenum) GLU_FILL);
-	gluSphere(quadObj, radius, 16, 16);
+	gluSphere(quadObj, radius, 100, 100);
 	gluDeleteQuadric(quadObj);
 	return True;
 }
@@ -397,7 +408,7 @@ draw_moebius_ant(float *Material, int mono)
 
 	glEnable(GL_LIGHTING);
 
-	ant_step += 0.3;
+	ant_step += 0.05;
 	return True;
 }
 
@@ -543,7 +554,7 @@ draw_moebius_strip(ModeInfo * mi)
 			return False;
 		glPopMatrix();
 	}
-	mp->ant_position += 1;
+	mp->ant_position += 0.5;
 	return True;
 }
 #undef MoebiusDivisions
@@ -559,7 +570,26 @@ reshape_moebius(ModeInfo * mi, int width, int height)
 	glLoadIdentity();
 	glFrustum(-1.0, 1.0, -1.0, 1.0, 5.0, 15.0);
 	glMatrixMode(GL_MODELVIEW);
-	if (width >= 1024) {
+	glEnable(GL_BLEND);
+	glBlendFunc(GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
+	if (width >= 7680) {
+		glEnable(GL_LINE_SMOOTH);
+		glLineWidth(10);
+		glPointSize(10);
+	} else if (width >= 5120) {
+		glEnable(GL_LINE_SMOOTH);
+		glLineWidth(7);
+		glPointSize(7);
+	} else if (width >= 3840) {
+		glEnable(GL_LINE_SMOOTH);
+		glLineWidth(6);
+		glPointSize(6);
+	} else if (width >= 1920) {
+		glEnable(GL_LINE_SMOOTH);
+		glLineWidth(5);
+		glPointSize(5);
+	} else if (width >= 1024) {
+		glEnable(GL_LINE_SMOOTH);
 		glLineWidth(3);
 		glPointSize(3);
 	} else if (width >= 512) {
@@ -626,9 +656,9 @@ rotate(GLfloat *pos, GLfloat *v, GLfloat *dv, GLfloat max_v, Bool verbose)
 
   /* tick position */
   if (ppos < 0)
-    ppos = -(ppos + *v);
+    ppos = -(ppos + *v / 2.5);
   else
-    ppos += *v;
+    ppos += *v / 2.5;
 
   if (ppos > 1.0)
     ppos -= 1.0;
@@ -708,7 +738,6 @@ init_moebius(ModeInfo * mi)
 
 	MI_INIT(mi, moebius);
 	mp = &moebius[MI_SCREEN(mi)];
-	mp->step = NRAND(90);
 	mp->ant_position = NRAND(90);
 
 	mp->rotx = FLOATRAND(1.0) * RANDSIGN();
@@ -797,8 +826,6 @@ draw_moebius(ModeInfo * mi)
 	glFlush();
 
 	glXSwapBuffers(display, window);
-
-	mp->step += 0.025;
 }
 
 #ifndef STANDALONE
