@@ -90,12 +90,6 @@ LockStruct  LockProcs[] =
 	 100000, -30, 5, 1, 64, 1.0, (char *) "",
 	 (char *) "Shows an auto-solving Bevel or Helicopter Cube", 0, NULL},
 #endif
-#ifdef MODE_billiards
-	{(char *) "billiards", init_billiards, draw_billiards, release_billiards,
-	 refresh_billiards, init_billiards, (ModeHook *) NULL, &billiards_opts,
-	 200000, 6, 30, 1, 64, 0.3, (char *) "",
-	 (char *) "Shows billiards", 0, NULL},
-#endif
 #ifdef MODE_blot
 	{(char *) "blot", init_blot, draw_blot, release_blot,
 	 refresh_blot, init_blot, free_blot, &blot_opts,
@@ -558,6 +552,12 @@ LockStruct  LockProcs[] =
 	 20000, 10, 1, 0, 64, 1.0, (char *) "",
 	 (char *) "Shows Pacman(tm)", 0, NULL},
 #endif
+#ifdef MODE_paterson
+	{(char *) "paterson", init_paterson, draw_paterson, release_paterson,
+	 init_paterson, init_paterson, (ModeHook *) NULL, &paterson_opts,
+	 50000, -3, 2000, -32, 64, 1.0, (char *) "",
+	 (char *) "Shows Paterson's Worm Paths", 0, NULL},
+#endif
 #ifdef MODE_penrose
 	{(char *) "penrose", init_penrose, draw_penrose, release_penrose,
 	 init_penrose, init_penrose, (ModeHook *) NULL, &penrose_opts,
@@ -713,6 +713,12 @@ LockStruct  LockProcs[] =
 	 5000, -40, 350, 1, 64, 1.0, (char *) "",
 	 (char *) "Shows a helical locus of points", 0, NULL},
 #endif
+#ifdef MODE_spirolateral
+	{(char *) "spirolateral", init_spirolateral, draw_spirolateral, release_spirolateral,
+	 refresh_spirolateral, init_spirolateral, (ModeHook *) NULL, &spirolateral_opts,
+	 40000, -16, -32, 1, 64, 1.0, (char *) "",
+	 (char *) "Shows Odds' Spirolaterals", 0, NULL},
+#endif
 #ifdef MODE_spline
 	{(char *) "spline", init_spline, draw_spline, release_spline,
 	 refresh_spline, init_spline, (ModeHook *) NULL, &spline_opts,
