@@ -1,4 +1,4 @@
-#if !defined( lint ) && !defined( SABER )
+#if 0
 static const char sccsid[] = "@(#)vis.c	4.07 97/01/30 xlockmore";
 
 #endif
@@ -310,10 +310,10 @@ defaultVisualInfo(Display * display, int screen)
 }
 
 /* has_writeable was hacked out of xscreensaver and modified for xlockmore
- * by Jouk Jansen <joukj@hrem.stm.tudelft.nl>
+ * by Jouk Jansen <joukj AT hrem.nano.tudelft.nl>
  *
  * xscreensaver, Copyright (c) 1993, 1994, 1995, 1996, 1997, 1998
- *  by Jamie Zawinski <jwz@jwz.org>
+ *  by Jamie Zawinski <jwz AT jwz.org>
  *
  * Permission to use, copy, modify, distribute, and sell this software and its
  * documentation for any purpose is hereby granted without fee, provided that
